==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/gm_meta.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_meta.lang.inc.php 2018-09-05
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_META_DELETE' => 'Löschen',
	'GM_META_ERROR' => 'Meta-Angabe leer',
	'GM_META_EXISTS' => 'Meta-Angabe bereits vorhanden',
	'GM_META_KEY' => '<strong>oder</strong> Eingabe einer Meta-Angabe',
	'GM_META_LANG' => 'Sprache',
	'GM_META_LANG_EMPTY' => 'Sie haben nicht alle notwendigen Angaben hinterlegt.',
	'GM_META_REQUIRED' => 'Diese Meta-Angabe ist vorbelegt und kann nicht gelöscht werden.',
	'GM_META_TITLE_AUTHOR' => 'Author',
	'GM_META_TITLE_COMPANY' => 'Company',
	'GM_META_TITLE_DESCRIPTION' => 'Description',
	'GM_META_TITLE_KEYWORDS' => 'Keywords',
	'GM_META_TITLE_PAGE_TOPIC' => 'Page-Topic',
	'GM_META_TITLE_PUBLISHER' => 'Publisher',
	'GM_META_TITLE_REPLY_TO' => 'Reply-To',
	'GM_META_TITLE_REVISIT_AFTER' => 'Revisit-After',
	'GM_META_TITLE_ROBOTS' => 'Robots',
	'GM_META_VALUE' => 'Wert',
	'GM_PRE_META_KEY' => 'Auswahl einer vordefinierten Meta-Angabe',
	'GM_TITLE_SHOW_STANDARD_META_TITLE' => 'Standard Meta-Titel Anzeige',
	'GM_TITLE_SHOW_STANDARD_META_TITLE_AFTER' => 'nach dem Meta-Titel',
	'GM_TITLE_SHOW_STANDARD_META_TITLE_BEFORE' => 'vor dem Meta-Titel',
	'GM_TITLE_STANDARD_META_TITLE' => 'Standard Meta-Titel',
	'GM_TITLE_STANDARD_META_TITLE_SEPARATOR' => 'Trennzeichen für Standard Meta-Titel',
	'GM_TITLE_STANDARD_META_TITLE_UPDATED' => 'Einstellungen aktualisiert',
	'GM_TITLE_USE_STANDARD_META_TITLE' => 'Standard Meta-Titel verwenden?',
	'GM_TITLE_USE_STANDARD_META_TITLE_NO' => 'Nein',
	'GM_TITLE_USE_STANDARD_META_TITLE_YES' => 'Ja',
	'HEADING_META_IMPORTANT' => 'Wichtige ',
	'HEADING_META_UNIMPORTANT' => 'Weitere ',
	'HEADING_SUB_TITLE' => 'Gambio',
	'HEADING_TITLE' => 'Suchmaschinenoptimierung',
	'MENU_TITLE_GM_META' => 'Meta-Angaben',
	'MENU_TITLE_GM_META_NEW' => 'neue Meta-Angaben',
	'MENU_TITLE_GM_META_OPTIONS' => 'Meta-Titel Einstellungen',
	'MENU_TITLE_GM_META_OPTIONS_1' => ' - englisches Profil',
	'MENU_TITLE_GM_META_OPTIONS_2' => ' - deutsches Profil'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/gm_meta.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	gm_meta.lang.inc.php 2018-09-05
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2017 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'GM_META_DELETE' => 'Löschen',
	'GM_META_ERROR' => 'Meta-Angabe leer',
	'GM_META_EXISTS' => 'Meta-Angabe bereits vorhanden',
	'GM_META_KEY' => '<strong>oder</strong> Eingabe einer Meta-Angabe',
	'GM_META_LANG' => 'Sprache',
	'GM_META_LANG_EMPTY' => 'Du hast nicht alle notwendigen Angaben hinterlegt.',
	'GM_META_REQUIRED' => 'Diese Meta-Angabe ist vorbelegt und kann nicht gelöscht werden.',
	'GM_META_TITLE_AUTHOR' => 'Author',
	'GM_META_TITLE_COMPANY' => 'Company',
	'GM_META_TITLE_DESCRIPTION' => 'Description',
	'GM_META_TITLE_KEYWORDS' => 'Keywords',
	'GM_META_TITLE_PAGE_TOPIC' => 'Page-Topic',
	'GM_META_TITLE_PUBLISHER' => 'Publisher',
	'GM_META_TITLE_REPLY_TO' => 'Reply-To',
	'GM_META_TITLE_REVISIT_AFTER' => 'Revisit-After',
	'GM_META_TITLE_ROBOTS' => 'Robots',
	'GM_META_VALUE' => 'Wert',
	'GM_PRE_META_KEY' => 'Auswahl einer vordefinierten Meta-Angabe',
	'GM_TITLE_SHOW_STANDARD_META_TITLE' => 'Standard Meta-Titel Anzeige',
	'GM_TITLE_SHOW_STANDARD_META_TITLE_AFTER' => 'nach dem Meta-Titel',
	'GM_TITLE_SHOW_STANDARD_META_TITLE_BEFORE' => 'vor dem Meta-Titel',
	'GM_TITLE_STANDARD_META_TITLE' => 'Standard Meta-Titel',
	'GM_TITLE_STANDARD_META_TITLE_SEPARATOR' => 'Trennzeichen für Standard Meta-Titel',
	'GM_TITLE_STANDARD_META_TITLE_UPDATED' => 'Einstellungen aktualisiert',
	'GM_TITLE_USE_STANDARD_META_TITLE' => 'Standard Meta-Titel verwenden?',
	'GM_TITLE_USE_STANDARD_META_TITLE_NO' => 'Nein',
	'GM_TITLE_USE_STANDARD_META_TITLE_YES' => 'Ja',
    'GM_TITLE_CHANGE_CATEGORY_META_INDEX' => 'Folgeseiten in Kategorien indexieren?',
    'GM_TITLE_CHANGE_CATEGORY_META_INDEX_DESC' => 'Mit index,follow erlaubst du Suchmaschinen, auch paginierte Kategorie-Seiten zu indexieren. Empfohlen für bessere Sichtbarkeit.',
    'GM_TITLE_CHANGE_CATEGORY_META_INDEX_NO' => 'Nein',
    'GM_TITLE_CHANGE_CATEGORY_META_INDEX_YES' => 'Ja',
	'HEADING_META_IMPORTANT' => 'Wichtige ',
	'HEADING_META_UNIMPORTANT' => 'Weitere ',
	'HEADING_SUB_TITLE' => 'Gambio',
	'HEADING_TITLE' => 'Suchmaschinenoptimierung',
	'MENU_TITLE_GM_META' => 'Meta-Angaben',
	'MENU_TITLE_GM_META_NEW' => 'neue Meta-Angaben',
	'MENU_TITLE_GM_META_OPTIONS' => 'Meta-Titel Einstellungen',
	'MENU_TITLE_GM_META_OPTIONS_1' => ' - englisches Profil',
	'MENU_TITLE_GM_META_OPTIONS_2' => ' - deutsches Profil'
);
